@@ -114,10 +114,8 @@ attachmentDialog.prototype = {
             }
         }        
         else {
-            for (var nCount=0;nCount<this.file_input_count;nCount++) {
-                if(this.form['json_'+nCount]) {
-                    this.form['json_'+nCount].value = sObj;
-                }
+            if(this.form['json_0']) {
+                this.form['json_0'].value = sObj;
             }
         }
         this.attachmentsChanged = true;
@@ -125,18 +123,20 @@ attachmentDialog.prototype = {
     },
     createFileInput: function () {
         var sId = 'file_' + (this.file_input_count);
-        var oNode = newnode('input',0,{
+        var oNodeJson, oNode = newnode('input',0,{
                                         type:"file",
                                         size:"40",
                                         name:sId,
                                         id:sId,
                                         className:"inputElementAttachment"
                                         });
-        var oNodeJson = newnode('input',0,{
+        if (this.file_input_count === 0) {
+	        oNodeJson = newnode('input',0,{
                                         type:"hidden",
                                         name:'json_'+(this.file_input_count),
                                         id:'json_'+(this.file_input_count)
                                         });
+        }
         if (IE) {
             // prevent entering file path manually
             jQuery(oNode).keypress(function(event){
@@ -150,13 +150,15 @@ attachmentDialog.prototype = {
         });
         this.last_input = oNode;
         var outerDiv1 = newnode("div");
-        var outerDiv2 = newnode("div");        
         outerDiv1.appendChild(oNode);
-        outerDiv2.appendChild(oNodeJson);
         this.form.appendChild(outerDiv1);
-        this.form.appendChild(outerDiv2);
         this.all_input_fields.push(oNode);
-        this.all_input_fields.push(oNodeJson);        
+        if (oNodeJson) {
+            var outerDiv2 = newnode("div");
+            outerDiv2.appendChild(oNodeJson);
+            this.form.appendChild(outerDiv2);
+            this.all_input_fields.push(oNodeJson);
+        }
         return sId;
     },
     openPopup: function () {
@@ -245,9 +247,15 @@ attachmentDialog.prototype = {
 //            hideNode("modal-dialog");
 //            $("modal-dialog").style.display = "none";
         }
+        this.open = false;
         this.file_name_list = this.file_name_list.concat(this.temp_list);
         this.callOnOK(this.file_name_list);    
         this.live_grid.disable();
+        if (this.last_input !== null) {
+            this.form.removeChild(this.last_input.parentNode);
+        }
+        this.last_input = null;
+        this.file_input_count++;
     },
     showAttachedFiles: function () {
         return this.file_name_list;
