@@ -63,7 +63,7 @@ AutoComplete.prototype.onTextBlur = function () {
 AutoComplete.prototype.onTextChange = function(evt) {
     var parent = this;
     if (!evt) evt = event;
-    a = evt.keyCode;    
+    a = evt.keyCode;
    this.AutoComplete.cancelRequest = false;
     switch (a) {
         case 27: //ESC
@@ -76,7 +76,7 @@ AutoComplete.prototype.onTextChange = function(evt) {
         case 40:    // DOWN
             parent.AutoComplete.keyUpDown(true);
             break;
-        case 16: case 17: case 18: case 35: case 36: case 37: case 39: 
+        case 16: case 17: case 18: case 35: case 36: case 37: case 39:
            // ignore: SHIFT / CTRL / ALT / POS1 / END / LEFT / RIGHT;
             return true;
         case 13: case 9: // ENTER
@@ -139,8 +139,8 @@ AutoComplete.prototype.keyUpDown = function (up) {
     }
 };
 
-AutoComplete.prototype.keyEnter = function () {
-    var _rb = true;
+AutoComplete.prototype.keyEnter = function (code) {
+    var _rb = code === 13 ? false : true;
     var elem = document.getElementById("ac_" + this.currSelected);
     if (elem) {
         var st = this.oText.scrollTop;
