@@ -1017,16 +1017,12 @@ var currentCardId = 0;
 var contactCardRowId = 1;
 var cbContainers = new Array();
 var selectedObjCard = new Array();
-var currentColumnToWrite = null;
 var countContactCards = 0;
-var contacCardWidth = "";
 var scrollerCbar = "";
-var countColumnCardstoView = 0;
 var topCardIndex = 0;
 var oldTopCardIndex = -1;
 var activeCardIdHead = 0;
 var firstViewOfContactGrid = 1;
-var indexofContact = 0;
 var cardsToView;
 var cardsPerRowToView;
 var isDistributionListSelected = 0;
@@ -1107,72 +1103,65 @@ function showContactCards()
 
 var scrollingProgress = false;
 
-function scrollCardView(e)
-{
-	if(scrollingProgress) return;
-	scrollingProgress = true;
-	var columnCards1 = $("column_1");
-	var columnCards2 = $("column_2");
-	var columnCards3 = $("column_3");
-	var columnCards4 = $("column_4");
+function scrollCardView(e) {
+    
+    var contactCardWidth = $("column_1").offsetWidth;
+    if (!scrollerCbar.scrollLeft) {
+        topCardIndex = 0;
+    } else {
+        topCardIndex = cardsPerRowToView * Math.max(0,
+            Math.min(Math.ceil(countContactCards / cardsPerRowToView),
+                     Math.ceil(scrollerCbar.scrollLeft / contactCardWidth)));
+    }
+    
+    if (oldTopCardIndex == topCardIndex) return;
+    oldTopCardIndex = topCardIndex;
+    
+    if (scrollingProgress) return;
+    scrollingProgress = true;
+    scrollCardRequest(topCardIndex);
+}
 
-	contacCardWidth = columnCards1.offsetWidth;
-	if(!scrollerCbar.scrollLeft)
-		topCardIndex = 0
-	else
-		topCardIndex = Math.max(0, Math.min(Math.ceil(countContactCards / cardsPerRowToView),
-				                            Math.ceil(scrollerCbar.scrollLeft / contacCardWidth)
-										   )
-							    ) * cardsPerRowToView;
-
-	countColumnCardstoView = 0;
-	if(oldTopCardIndex==topCardIndex) {
-		scrollingProgress = false;
-		return;
-	}
-	oldTopCardIndex = topCardIndex;
-
-	var aCardContent = new Array();
-	var aColumnContent = new Array();
-
-	var collection={};
-	collection.objects=contactsSelection2.collection.objects.slice(topCardIndex,topCardIndex + cardsToView);
-	collection.columns=["display_name", "first_name", "last_name","title",
+function scrollCardRequest(myIndex) {
+    var collection = {};
+    collection.objects = contactsSelection2.collection.objects.slice(
+        myIndex, myIndex + cardsToView);
+    collection.columns=["display_name", "first_name", "last_name","title",
         "street_business", "postal_code_business", "city_business",
         "state_business", "telephone_business1", "email1","color_label",
         "mark_as_distributionlist", "distribution_list", "private_flag",
         "cellular_telephone1", "cellular_telephone2", "telephone_business2",
-        "telephone_company", "telephone_home1", "telephone_home2", "email2", "company"];
-	OXCache.newRequest(null,"contacts",collection,
-	null,function cb(data) {
-		removeChildNodes(columnCards1);
-        removeChildNodes(columnCards2);
-        removeChildNodes(columnCards3);
-        removeChildNodes(columnCards4);
-        scrollingProgress = false;
-        for(var i=0;i<data.objects.length;i++) {
-           var objIndex=contactsSelection2.collection.map_objects.get(data.objects[i]);
-           var index =objIndex-topCardIndex-1;
-           aCardContent[index] = data.objects[i];
-           aColumnContent[index] = currentColumnToWrite;
-           countColumnCardstoView++;
-           indexofContact++;
+        "telephone_company", "telephone_home1", "telephone_home2", "email2",
+        "company"];
+    OXCache.newRequest(null, "contacts", collection,
+    null, function cb(data) {
+        var columnCards = [$("column_1"), $("column_2"),
+                           $("column_3"), $("column_4")];
+        
+        for (var i = 0; i < columnCards.length; i++) {
+            removeChildNodes(columnCards[i]);
         }
-        for (var j=0; j<aCardContent.length; j++) {
-            if(j < cardsPerRowToView) { currentColumnToWrite = columnCards1; }
-            else if(j < (cardsPerRowToView*2)) { currentColumnToWrite = columnCards2; }
-            else if(j < (cardsPerRowToView*3)) { currentColumnToWrite = columnCards3; }
-            else if(j < (cardsPerRowToView*4)) { currentColumnToWrite = columnCards4; }
-            else { currentColumnToWrite = ""; }
-            writeCards(j+topCardIndex, currentColumnToWrite, aCardContent[j]);
+        
+        var aCardContent = [];
+        for(var i = 0; i < data.objects.length; i++) {
+            var obj = data.objects[i];
+            var objIndex = contactsSelection2.collection.map_objects.get(obj);
+            var index = objIndex - myIndex - 1;
+            aCardContent[index] = obj;
+        }
+        for (var j=0; j < aCardContent.length; j++) {
+            var column = columnCards[Math.floor(j / cardsPerRowToView)];
+            writeCards(j+myIndex, column, aCardContent[j]);
         }
         if (objContactCardFunctions) {
-        	objContactCardFunctions.updateCardStyle();
+            objContactCardFunctions.updateCardStyle();
         }
         // now fire event
         triggerEvent("Selected", contactsSelection2.getSelected());
+
+        if (topCardIndex != myIndex) return scrollCardRequest(topCardIndex);
+        scrollingProgress = false;
     });
-	return;
 }
 
 
@@ -2340,11 +2329,7 @@ function createNewContact (module, folder) {
 }
 /********************************** open Popup *****************************************************************/
 
-function closeContactPopUp(popContact, newFolderId)
-{
-	window.setTimeout(function () {
-	    popContact.windowController.close(true);
-	}, 50);
+function closeContactPopUp(popContact, newFolderId) {
 	if (currentpath2[0] == 'contacts' && currentpath2[1] == 'detail') {
 	    triggerEvent("OX_Switch_View","contacts/detail/overview");
 		if (newFolderId != activefolder) {
@@ -2357,6 +2342,11 @@ function closeContactPopUp(popContact, newFolderId)
 			reloadContactDetailView();
 		}
 	}
+	if (!ox.api.window.isEmbedded() && ox.browser.Win8 && (ox.browser.IE10 || ox.browser.IE11)) {
+	    setTimeout(function() {
+	        ox.api.window.core.triggerEvent("OX_Folder_Objects_Changed", newFolderId || activefolder);
+	    }, 0);
+	}
 }
 /********************************** Show Contacts by ABC ********************************/
 
