@@ -21,7 +21,7 @@ var oLastSelectedInfoObject = -1;
 var propertiesPopUp;
 var bLoadedDetailViewOverView = false;
 var aPrintDetailInfoStore;
-var infostoreFolderPath;
+var infostoreFolderPath, infostoreSearchObject = null;
 
 registerPrintView("infostore/list");
 registerPrintView("infostore/split/overview");
@@ -43,9 +43,10 @@ registerView("infostore",
         null,
         null,       
         function() {
-            triggerEvent("Selected",[]);        
+            triggerEvent("Selected",[]);
         }, 
         function() {
+            infostoreSearchObject = null;
             if (infostoreRequest) {
                 OXCache.unregister(infostoreRequest.uniqueName);
                 infostoreRequest=null;
