@@ -1669,23 +1669,26 @@ LiveGrid2.prototype = {
             if (Self.hover && !Self.disablehover) Self.hover.enable();
             resizeEvents.register("Resized", Self.scroll_cb);
             register("LanguageChanged",Self.language_cb);
-            if (Self.dndModule && (Self.dndModule != "links")) {
-                var disabled;
-                var validfield;
-                switch(Self.dndModule) {
-                    case "calendar": disabled=calendardefaultdisabled;  validfield="title"; break;
-                    case "tasks":   disabled=taskdefaultdisabled; validfield="title"; break;
-                    case "contacts": disabled=contactdefaultdisabled; validfield="display_name"; break;
-                    case "infostore": disabled=infostoredefaultdisabled; validfield="title"; break;
-                    case "mail": disabled=maildefaultdisabled; validfield="subject"; break;
-                }
-                Self.dragEvent = registerSource(Self.heightDiv, Self.dndModule, function() 
-                {
-                    var myelements=clone(Self.selection.getSelected());
-                    objMoveCopy.begin(Self.dndModule,myelements);
-                    return objMoveCopy;
-                },null,null,disabled,defaultdisabledremove);
+        }
+        if (!Self.dragEvent && Self.dndModule && (Self.dndModule != "links")) {
+            var disabled;
+            var validfield;
+            switch(Self.dndModule) {
+                case "calendar": disabled=calendardefaultdisabled;  validfield="title"; break;
+                case "tasks":   disabled=taskdefaultdisabled; validfield="title"; break;
+                case "contacts": disabled=contactdefaultdisabled; validfield="display_name"; break;
+                case "infostore": disabled=infostoredefaultdisabled; validfield="title"; break;
+                case "mail": disabled=maildefaultdisabled; validfield="subject"; break;
             }
+            Self.dragEvent = registerSource(Self.heightDiv, Self.dndModule, function() 
+            {
+                var myelements=clone(Self.selection.getSelected());
+                objMoveCopy.begin(Self.dndModule,myelements);
+                return objMoveCopy;
+            },null,null,disabled,defaultdisabledremove);
+        } else if (Self.dragEvent && !Self.dndModule) {
+            unregisterSource(this.parent, this.dragEvent);
+            this.dragEvent = null;
         }
         var oldFocus = 0, fallbackSelection;
         var returnObject=OXCache.newRequest(null, this.module,
@@ -1758,8 +1761,9 @@ LiveGrid2.prototype = {
         unregister("LanguageChanged",this.language_cb);
         if (this.hover) this.hover.disable();
         resizeEvents.unregister("Resized", this.scroll_cb);
-        if (this.dndModule) {
+        if (this.dragEvent) {
             unregisterSource(this.parent, this.dragEvent);
+            this.dragEvent = null;
         }
     },
     
