@@ -323,10 +323,15 @@ ox.mail.itip = {
             cb = options.callback,
             iMIPAttachments = (message.attachments_html
                     || message.attachments_html_noimage || message.attachments_plain);
+        ox.mail.itip.msgctx = message.folder_id + "." + message.id;
         if (iMIPAttachments && corewindow.ox.upsell.isVisible("calendar")) {
             var imipObject = {};
             var join = new Join(function() {
-                cb(isEmpty(imipObject) ? undefined : imipObject);
+                if (ox.mail.itip.msgctx === message.folder_id + "." + message.id) {
+                    ox.mail.itip.msgctx = undefined;
+                    cb(isEmpty(imipObject) ? undefined : imipObject);
+                }
+                ox.mail.itip.msgctx = undefined;
             });
             var last = join.add();
             
@@ -369,6 +374,7 @@ ox.mail.itip = {
             
             last();
         } else {
+            ox.mail.itip.msgctx = undefined;
             cb();
         }
     },
