@@ -1560,9 +1560,14 @@ Participants.prototype = {
 	                        break;
 	                    }
 	                }
+	                // map id to user_id if not present
+	                var id = cb[i].user_id;
+                    if (cb[i].user_id === -1) {
+                        id = cb[i].id;
+                    }
 	                // type 1 = internal user
 	                var folder = cb[i].type === 1 ? 6 : 0;
-	                Self.tmpArrayContact[count++] = ["contact_" + cb[i].user_id, 
+	                Self.tmpArrayContact[count++] = ["contact_" +id, 
 	                                                 folder, cb[i].display_name, userstatus, 
 	                                                 message, "", "contact", i, 0];
 	                Self.internalStorage2.groups.push(false);
@@ -1583,8 +1588,6 @@ Participants.prototype = {
 		if(Self.groupToReq.length > 0) {
 		    // define callback
 	        var groupToReqCB = joint.add(function(cb) {
-	            var count = 0;
-	            var tmpArray = new Array();
 	            var toGetTmp = new Array();
 	            for (i in cb) {
 	                for (k in cb[i].members) {
