@@ -227,7 +227,7 @@ ox.gui.FolderTree = ox.gui.Tree.extend({
                     src = "infostore";
                     $(node.dom.title.parentNode).removeClass("font-style-low");
 
-                    if (data.id === "9" || data.id === "10" || data.id === "14" || data.id === "15") {
+                    if (data.id === "9" || data.id === "10" || data.id === "14") {
 
                         node.selectable = false;
                     }
